Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1478)

Unified Diff: android_webview/java/src/org/chromium/android_webview/DefaultVideoPosterRequestHandler.java

Issue 284123004: [android_webview] Add more params to request intercepting. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix accidentally broken test Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: android_webview/java/src/org/chromium/android_webview/DefaultVideoPosterRequestHandler.java
diff --git a/android_webview/java/src/org/chromium/android_webview/DefaultVideoPosterRequestHandler.java b/android_webview/java/src/org/chromium/android_webview/DefaultVideoPosterRequestHandler.java
index df2290abb481c9cfbe17cc224f12103fb52d1124..aaed9f8ec4db312afc151424d8b55cb35abb7be1 100644
--- a/android_webview/java/src/org/chromium/android_webview/DefaultVideoPosterRequestHandler.java
+++ b/android_webview/java/src/org/chromium/android_webview/DefaultVideoPosterRequestHandler.java
@@ -81,14 +81,14 @@ public class DefaultVideoPosterRequestHandler {
* Used to get the image if the url is mDefaultVideoPosterURL.
*
* @param url the url requested
* @return InterceptedRequestData which caller can get the image if the url is
* the default video poster URL, otherwise null is returned.
*/
- public InterceptedRequestData shouldInterceptRequest(final String url) {
+ public AwWebResourceResponse shouldInterceptRequest(final String url) {
if (!mDefaultVideoPosterURL.equals(url)) return null;
try {
- return new InterceptedRequestData("image/png", null, getInputStream(mContentClient));
+ return new AwWebResourceResponse("image/png", null, getInputStream(mContentClient));
} catch (IOException e) {
Log.e(TAG, null, e);
return null;
@@ -81,14 +81,14 @@ public class DefaultVideoPosterRequestHandler {
*
* @param url the url requested
- * @return InterceptedRequestData which caller can get the image if the url is
+ * @return AwWebResourceResponse which caller can get the image if the url is
* the default video poster URL, otherwise null is returned.
*/

Powered by Google App Engine
This is Rietveld 408576698